#
# spec file for package python-python-poppler
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 LISA GmbH ,Bingen, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-poppler
Version:        0.4.1
Release:        1.3
Summary:        Python binding to the poppler-cpp library
License:        GPL-2.0-only
URL:            https://github.com/cbrunet/python-poppler
Source:         https://github.com/cbrunet/python-poppler/archive/refs/tags/v%{version}.tar.gz#/python-poppler-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE Build against system pybind11
Patch0:         use-system-pybind11.patch
# PATCH-FIX-UPSTREAM gh#cbrunet/python-poppler#92
Patch1:         support-poppler-25.01.patch
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module meson-python}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pybind11-devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  ninja
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(poppler)
# some tests require this
BuildRequires:  poppler-data
%python_subpackages

%description
python-poppler is a Python binding to the poppler-cpp library. It allows to
read, render, or modify PDF documents. More specifically, it currently allows
to:
    read an modify document meta data;
    list and read embedded documents;
    list the fonts used by the document;
    search or extract text on a given page of the document;
    render a page to a raw image;
    get info about transitions effects between the pages;
    read the table of contents of the document.

%prep
%autosetup -p1 -n python-poppler-%version
rm -rf subprojects

%build
export CXXFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch tests

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitearch}/poppler
%{python_sitearch}/python_poppler-%{version}.dist-info

%changelog
* Mon Jan 20 2025 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-poppler-25.01.patch:
  * Support Poppler 25.01 changes.
* Mon Jan 13 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.1:
  * Fix non-pure build for meson-python
  * Tested with Python 3.11 and Poppler 23.04.0
  * Minimal supported Python version is now 3.7
  * Tested with Python 3.11 and Poppler 23.03.0
  * Build system is now meson, and package is PEP-517 compliant
  * Tested with Python 3.10 and Poppler 22.04.0
  * EmbeddedFile data() and checksum() now return bytes
  * Bugfix: Fixed typos in EmbeddedFile.modification_date and
    EmbeddedFile.is_valid
  * Bugfix: Fixed typo in page.search
  * Bugfix: Fix underscore position in two attributes of the Rotation Enum
  * Bugfix: Reading pdf_version now requires unlocked document
  * Bugfix: Ensure document was loaded before creating Document object
- Drop patch fix-image-argb.patch, no longer required.
- No longer use disabled service to update, we don't need to clean up
  pybind11 sources, switch to the GitHub tarball to keep the testsuite.
- Refresh patch use-system-pybind11.patch to work with meson.
* Wed Aug 23 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Fix build with newer rpm
* Fri Aug 27 2021 Ben Greiner <code@bnavigator.de>
- remove dangling series file
- skip failing test due to poppler 21.08.0 crash
  gh#cbrunet/python-poppler#39
* Mon Mar 22 2021 Hans-Peter Jansen <hpj@urpla.net>
- Add fix-image-argb.patch to fix image formatting with
  pybind11 >= 2.6.0
* Tue Oct  6 2020 Hans-Peter Jansen <hpj@urpla.net>
- Add use-system-pybind11.patch to use system provided pybind11
- Exclude pybind11 from _service
* Sat Oct  3 2020 Hans-Peter Jansen <hpj@urpla.net>
- Fix fdupes
- Package license
- Use %%pytest_arch
* Sat Oct  3 2020 hpj@urpla.net
- Update to version 0.2.2:
  * Put changelog in doc (#22)
  * lower required python version to 3.6 (#21)
  * Fix corrupted document buffer (#20)
* Thu Oct  1 2020 Hans-Peter Jansen <hpj@urpla.net>
- Switch to git release by disabled service (pypi is missing tests)
- Enable tests
* Thu Oct  1 2020 hpj@urpla.net
- Update to version 0.2.1+git20200930.d09bfc7:
  * fix initializer list for some compilers (#18)
  * invoke apidoc when running tox -e docs (#15)
  * Lower minimum poppler-cpp version to 0.26.0 (#13)
  * Documentation (#10)
  * Fixes for 20 08 (#11)
  * Verbose nested namespace syntax (not C++17) (#7)
  * fix include paths (#3)
  * ensure document is unlocked (#5)
  * Fixed byte order in image format string
  * Add automated tests for latest version of Poppler (#1)
- Remove fix-initializer-list-for-some-compilers.patch
* Wed Sep 30 2020 Hans-Peter Jansen <hpj@urpla.net>
- Apply fix-initializer-list-for-some-compilers.patch to fix a
  32bit build issue
* Fri Sep 25 2020 Hans-Peter Jansen <hpj@urpla.net>
- Version 0.2.1: initial build
